@@ -2,10 +2,12 @@
 
 from .motor_board import SRV4MotorBoardHardwareBackend
 from .power_board import SRV4PowerBoardHardwareBackend
+from .ruggeduino import SRV4RuggeduinoHardwareBackend
 from .servo_board import SRV4ServoBoardHardwareBackend
 
 __all__ = [
     "SRV4MotorBoardHardwareBackend",
     "SRV4PowerBoardHardwareBackend",
     "SRV4ServoBoardHardwareBackend",
+    "SRV4RuggeduinoHardwareBackend",
 ]
